"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var classnames_1 = __importDefault(require("classnames"));
var camelCase_1 = __importDefault(require("lodash/camelCase"));
exports.statusMap = {
    enterStart: 'enter-start',
    entering: 'entering',
    enterEnd: 'enter-end',
    leaveStart: 'leave-start',
    leaving: 'leaving',
    leaveEnd: 'leave-end',
};
var Motion = /** @class */ (function (_super) {
    __extends(Motion, _super);
    function Motion(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            status: 'leaveEnd',
        };
        _this.timer = null;
        _this.statusChange = function (status) {
            var onStatusChange = _this.props.onStatusChange;
            if (onStatusChange) {
                onStatusChange(status);
            }
        };
        _this.enterStart = function () {
            var onEnter = _this.props.onEnter;
            var status = camelCase_1.default(exports.statusMap.enterStart);
            _this.setState({
                status: status,
            }, function () {
                if (onEnter)
                    onEnter();
                _this.statusChange(status);
                requestAnimationFrame(_this.entering);
            });
        };
        _this.entering = function () {
            var status = camelCase_1.default(exports.statusMap.entering);
            _this.setState({
                status: status,
            }, function () {
                _this.statusChange(status);
                _this.timer = setTimeout(function () {
                    _this.enterEnd();
                }, _this.props.duration);
            });
        };
        _this.enterEnd = function () {
            var onEnterEnd = _this.props.onEnterEnd;
            var status = camelCase_1.default(exports.statusMap.enterEnd);
            _this.setState({
                status: status,
            }, function () {
                _this.statusChange(status);
                if (onEnterEnd)
                    onEnterEnd();
            });
        };
        _this.enterMotion = function () {
            _this.enterStart();
        };
        _this.leaveStart = function () {
            var onLeave = _this.props.onLeave;
            var status = camelCase_1.default(exports.statusMap.leaveStart);
            _this.setState({
                status: status,
            }, function () {
                if (onLeave)
                    onLeave();
                _this.statusChange(status);
                requestAnimationFrame(_this.leaving);
            });
        };
        _this.leaving = function () {
            var status = camelCase_1.default(exports.statusMap.leaving);
            _this.setState({
                status: status,
            }, function () {
                _this.statusChange(status);
                _this.timer = setTimeout(function () {
                    _this.leaveEnd();
                }, _this.props.duration);
            });
        };
        _this.leaveEnd = function () {
            var onLeaveEnd = _this.props.onLeaveEnd;
            var status = camelCase_1.default(exports.statusMap.leaveEnd);
            _this.setState({
                status: status,
            }, function () {
                _this.statusChange(status);
                if (onLeaveEnd)
                    onLeaveEnd();
            });
        };
        _this.leaveMotion = function () {
            _this.leaveStart();
        };
        _this.play = function () {
            _this.clearTimer();
            if (_this.props.visible) {
                _this.enterMotion();
            }
            else {
                _this.leaveMotion();
            }
        };
        _this.clearTimer = function () {
            if (_this.timer) {
                clearTimeout(_this.timer);
                _this.timer = null;
            }
        };
        if (props.visible) {
            _this.state = {
                status: 'enterStart',
            };
        }
        return _this;
    }
    Motion.prototype.componentDidMount = function () {
        if (this.props.visible) {
            requestAnimationFrame(this.play);
        }
    };
    Motion.prototype.componentDidUpdate = function (prev) {
        var visible = this.props.visible;
        if (prev.visible !== visible) {
            requestAnimationFrame(this.play);
        }
    };
    Motion.prototype.componentWillUnmount = function () {
        this.clearTimer();
    };
    Motion.prototype.render = function () {
        var _a = this.props, children = _a.children, classNames = _a.classNames, duration = _a.duration;
        var status = this.state.status;
        if (!react_1.default.isValidElement(children)) {
            return null;
        }
        var className = classnames_1.default(children.props.className, classNames + "-" + exports.statusMap[status]);
        var style = __assign(__assign({}, children.props.style), { transitionDuration: duration + "ms" });
        return react_1.default.cloneElement(react_1.default.Children.only(children), {
            className: className,
            style: style,
        });
    };
    Motion.defaultProps = {
        duration: 300,
    };
    return Motion;
}(react_1.default.Component));
exports.default = Motion;
//# sourceMappingURL=index.js.map