"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var nextAlignMap = {
    left: {
        L: null,
        R: 'center',
    },
    center: {
        L: 'left',
        R: 'right',
    },
    right: {
        L: 'center',
        R: null,
    },
    top: {
        T: null,
        B: 'middle',
    },
    middle: {
        T: 'top',
        B: 'bottom',
    },
    bottom: {
        T: 'middle',
        B: null,
    },
};
function getPlacement(placement, align) {
    if (['middle', 'center'].includes(align)) {
        align = '';
    }
    if (!align) {
        return placement;
    }
    return placement + "-" + align;
}
function checkContentOverflow(top, left, width, height) {
    if (top < 0) {
        return 'T';
    }
    if (left < 0) {
        return 'L';
    }
    if (top + height > window.innerHeight) {
        return 'B';
    }
    if (left + width > window.innerWidth) {
        return 'R';
    }
    return '';
}
function calculateTop(align, params) {
    var triggerRect = params.triggerRect, contentRect = params.contentRect, offsetY = params.offsetY, checkOverflow = params.checkOverflow;
    var bottom = triggerRect.bottom, height = triggerRect.height, left = triggerRect.left, width = triggerRect.width;
    var diffX = 0;
    switch (align) {
        case 'right':
            diffX = width - contentRect.width;
            break;
        case 'center':
            diffX = (width - contentRect.width) / 2;
            break;
        default:
            diffX = 0;
    }
    var t = bottom - height - contentRect.height - offsetY;
    var l = left + diffX;
    if (checkOverflow) {
        var overflow = checkContentOverflow(t, l, contentRect.width, contentRect.height);
        if (overflow) {
            if (overflow === 'T') {
                return calculateBottom(align, __assign(__assign({}, params), { checkOverflow: false }));
            }
            var nextAlign = nextAlignMap[align][overflow];
            if (nextAlign) {
                return calculateTop(nextAlign, params);
            }
        }
    }
    return { top: Math.round(t), left: Math.round(l), placement: getPlacement('top', align) };
}
exports.calculateTop = calculateTop;
function calculateRight(align, params) {
    var triggerRect = params.triggerRect, contentRect = params.contentRect, offsetX = params.offsetX, checkOverflow = params.checkOverflow;
    var top = triggerRect.top, height = triggerRect.height, right = triggerRect.right;
    var diffY = 0;
    switch (align) {
        case 'bottom':
            diffY = height - contentRect.height;
            break;
        case 'middle':
            diffY = (height - contentRect.height) / 2;
            break;
        default:
            diffY = 0;
    }
    var l = right + offsetX;
    var t = top + diffY;
    if (checkOverflow) {
        var overflow = checkContentOverflow(t, l, contentRect.width, contentRect.height);
        if (overflow) {
            if (overflow === 'R') {
                return calculateLeft(align, __assign(__assign({}, params), { checkOverflow: false }));
            }
            var nextAlign = nextAlignMap[align][overflow];
            if (nextAlign) {
                return calculateRight(nextAlign, params);
            }
        }
    }
    return { top: Math.round(t), left: Math.round(l), placement: getPlacement('right', align) };
}
exports.calculateRight = calculateRight;
function calculateBottom(align, params) {
    var triggerRect = params.triggerRect, contentRect = params.contentRect, offsetY = params.offsetY, checkOverflow = params.checkOverflow;
    var bottom = triggerRect.bottom, left = triggerRect.left, width = triggerRect.width;
    var diffX = 0;
    switch (align) {
        case 'right':
            diffX = width - contentRect.width;
            break;
        case 'center':
            diffX = (width - contentRect.width) / 2;
            break;
        default:
            diffX = 0;
    }
    var t = bottom + offsetY;
    var l = left + diffX;
    if (checkOverflow) {
        var overflow = checkContentOverflow(t, l, contentRect.width, contentRect.height);
        if (overflow) {
            if (overflow === 'B') {
                return calculateTop(align, __assign(__assign({}, params), { checkOverflow: false }));
            }
            var nextAlign = nextAlignMap[align][overflow];
            if (nextAlign) {
                return calculateBottom(nextAlign, params);
            }
        }
    }
    return { top: Math.round(t), left: Math.round(l), placement: getPlacement('bottom', align) };
}
exports.calculateBottom = calculateBottom;
function calculateLeft(align, params) {
    var triggerRect = params.triggerRect, contentRect = params.contentRect, offsetX = params.offsetX, checkOverflow = params.checkOverflow;
    var top = triggerRect.top, height = triggerRect.height, left = triggerRect.left;
    var diffY = 0;
    switch (align) {
        case 'bottom':
            diffY = height - contentRect.height;
            break;
        case 'middle':
            diffY = (height - contentRect.height) / 2;
            break;
        default:
            diffY = 0;
    }
    var l = left - contentRect.width - offsetX;
    var t = top + diffY;
    if (checkOverflow) {
        var overflow = checkContentOverflow(t, l, contentRect.width, contentRect.height);
        if (overflow) {
            if (overflow === 'L') {
                return calculateRight(align, __assign(__assign({}, params), { checkOverflow: false }));
            }
            var nextAlign = nextAlignMap[align][overflow];
            if (nextAlign) {
                return calculateLeft(nextAlign, params);
            }
        }
    }
    return { top: Math.round(t), left: Math.round(l), placement: getPlacement('left', align) };
}
exports.calculateLeft = calculateLeft;
//# sourceMappingURL=calculatePosition.js.map