/// <reference types="lodash" />
import React from 'react';
import { ContentChildProps } from './content';
import { TCalculateParams } from './calculatePosition';
declare const triggers: ["hover", "click", "focus"];
export declare type TriggerType = typeof triggers[number];
export interface PopupContentProps extends ContentChildProps {
}
declare const placementMap: {
    top: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    topRight: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    topLeft: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    right: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    rightTop: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    rightBottom: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    bottom: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    bottomRight: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    bottomLeft: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    left: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    leftTop: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
    leftBottom: (params: TCalculateParams) => {
        left: number;
        top: number;
        placement: string;
    };
};
declare type placementType = keyof typeof placementMap;
export interface IProps {
    content: React.ReactElement;
    children: React.ReactElement;
    trigger?: TriggerType;
    placement?: placementType;
    motionDuration?: number;
    motionClassName?: string;
    offset?: number | {
        x: number;
        y: number;
    };
    contentVisible?: boolean;
    checkOverflow?: boolean;
    closeDelay?: number;
    openDelay?: number;
    getContainer?: () => HTMLElement | false;
    onVisibleChange?: (visible: boolean) => void;
}
interface IState {
    visible: boolean;
    position: {
        left?: number;
        top?: number;
    };
    actualPlacement: string;
}
export default class Popup extends React.Component<IProps, IState> {
    static defaultProps: {
        trigger: string;
        placement: string;
        offset: number;
        closeDelay: number;
        openDelay: number;
        getContainer: () => HTMLElement;
    };
    timer: number | null;
    triggerRef: React.RefObject<HTMLElement>;
    triggerEle: HTMLElement | null;
    contentWrap: React.RefObject<HTMLDivElement> | null;
    state: {
        visible: boolean;
        position: {
            left: undefined;
            top: undefined;
        };
        actualPlacement: string;
    };
    constructor(props: IProps);
    componentDidMount(): void;
    componentDidUpdate(prevProps: IProps): void;
    componentWillUnmount(): void;
    getTriggerEle: () => HTMLElement | null;
    handleResetPosition: (() => void) & import("lodash").Cancelable;
    getContentWrap: (contentWrap: React.RefObject<HTMLDivElement>) => void;
    getContainer: () => HTMLElement;
    setVisible: (next: boolean, cb?: Function | undefined, delay?: boolean | undefined) => void;
    hide: () => void;
    calculateAndSetPosition: (triggerRect: DOMRect) => void;
    getTriggerHandle: (visible: boolean, childHandle?: Function | undefined, needCalculate?: boolean | undefined) => (e: React.MouseEvent<Element, MouseEvent>) => void;
    handleVisibleChange: (visible: boolean) => void;
    handleClickOutside: () => void;
    getTrigger: () => "click" | "focus" | "hover";
    renderChild: () => React.ReactElement<any, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)> | null) | (new (props: any) => React.Component<any, any, any>)> | null;
    renderContent: () => React.ReactElement<any, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)> | null) | (new (props: any) => React.Component<any, any, any>)> | null;
    render(): JSX.Element;
}
export {};
