"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var react_dom_1 = __importDefault(require("react-dom"));
var camelCase_1 = __importDefault(require("lodash/camelCase"));
var throttle_1 = __importDefault(require("lodash/throttle"));
var content_1 = __importDefault(require("./content"));
var calculatePosition_1 = require("./calculatePosition");
var types_1 = require("../../_util/types");
var triggers = types_1.tuple('hover', 'click', 'focus');
var placementMap = {
    top: function (params) { return calculatePosition_1.calculateTop('center', params); },
    topRight: function (params) { return calculatePosition_1.calculateTop('right', params); },
    topLeft: function (params) { return calculatePosition_1.calculateTop('left', params); },
    right: function (params) { return calculatePosition_1.calculateRight('middle', params); },
    rightTop: function (params) { return calculatePosition_1.calculateRight('top', params); },
    rightBottom: function (params) { return calculatePosition_1.calculateRight('bottom', params); },
    bottom: function (params) { return calculatePosition_1.calculateBottom('center', params); },
    bottomRight: function (params) { return calculatePosition_1.calculateBottom('right', params); },
    bottomLeft: function (params) { return calculatePosition_1.calculateBottom('left', params); },
    left: function (params) { return calculatePosition_1.calculateLeft('middle', params); },
    leftTop: function (params) { return calculatePosition_1.calculateLeft('top', params); },
    leftBottom: function (params) { return calculatePosition_1.calculateLeft('bottom', params); },
};
var Popup = /** @class */ (function (_super) {
    __extends(Popup, _super);
    function Popup(props) {
        var _this = _super.call(this, props) || this;
        _this.timer = null;
        _this.triggerRef = react_1.default.createRef();
        _this.triggerEle = null;
        _this.contentWrap = null;
        _this.state = {
            visible: false,
            position: {
                left: undefined,
                top: undefined,
            },
            actualPlacement: '',
        };
        _this.getTriggerEle = function () {
            var _a;
            if (_this.triggerEle) {
                return _this.triggerEle;
            }
            var triggerEle = (_a = _this.triggerRef) === null || _a === void 0 ? void 0 : _a.current;
            triggerEle = react_dom_1.default.findDOMNode(triggerEle);
            if (triggerEle) {
                _this.triggerEle = triggerEle;
            }
            else {
                _this.triggerEle = null;
            }
            return _this.triggerEle;
        };
        _this.handleResetPosition = throttle_1.default(function () {
            var triggerEle = _this.getTriggerEle();
            triggerEle && _this.calculateAndSetPosition(triggerEle.getBoundingClientRect());
        }, 50);
        _this.getContentWrap = function (contentWrap) {
            _this.contentWrap = contentWrap;
        };
        _this.getContainer = function () {
            var _a;
            var getContainer = _this.props.getContainer;
            var container = document.body;
            if (typeof getContainer === 'function') {
                container = getContainer();
            }
            if (container === false) {
                container = ((_a = _this.triggerEle) === null || _a === void 0 ? void 0 : _a.parentNode) || document.body;
            }
            return container;
        };
        _this.setVisible = function (next, cb, delay) {
            if (_this.timer) {
                clearTimeout(_this.timer);
            }
            var _a = _this.props, onVisibleChange = _a.onVisibleChange, _b = _a.closeDelay, closeDelay = _b === void 0 ? 100 : _b, _c = _a.openDelay, openDelay = _c === void 0 ? 100 : _c;
            var delayDuration = next ? openDelay : closeDelay;
            var setVisible = function () {
                _this.setState({ visible: next }, function () {
                    if (onVisibleChange)
                        onVisibleChange(next);
                    if (cb)
                        cb();
                });
            };
            if (delay && delayDuration) {
                _this.timer = window.setTimeout(setVisible, delayDuration);
            }
            else {
                setVisible();
            }
        };
        _this.hide = function () {
            _this.setVisible(false, undefined, false);
        };
        _this.calculateAndSetPosition = function (triggerRect) {
            var _a = _this.props, _b = _a.placement, placement = _b === void 0 ? 'bottom' : _b, _c = _a.offset, offset = _c === void 0 ? 0 : _c, _d = _a.checkOverflow, checkOverflow = _d === void 0 ? true : _d;
            var calculateFunc = placementMap[placement] || placementMap.bottom;
            var offsetX = 0;
            var offsetY = 0;
            if (typeof offset === 'number') {
                offsetX = offset;
                offsetY = offset;
            }
            else if (typeof offset === 'object') {
                offsetX = offset.x || 0;
                offsetY = offset.y || 0;
            }
            /*
             *因为不好确定content布局完成的时机并且为了确保位置计算时content的getBoundingClientRect一定有值
             *经测试一般repeat的值不会大于3
             */
            var repeat = 0;
            var setPosition = function () {
                var contentWrap = _this.contentWrap && _this.contentWrap.current;
                if (!contentWrap || !(contentWrap.offsetHeight && contentWrap.offsetWidth)) {
                    if (repeat < 50) {
                        requestAnimationFrame(setPosition);
                    }
                    repeat++;
                }
                else {
                    var position = calculateFunc({
                        triggerRect: triggerRect,
                        contentRect: contentWrap.getBoundingClientRect(),
                        offsetX: offsetX,
                        offsetY: offsetY,
                        checkOverflow: checkOverflow,
                    });
                    var container = _this.getContainer();
                    var containerRect = container.getBoundingClientRect();
                    var containerX = containerRect.left;
                    var containerY = containerRect.top;
                    var scrollX_1 = container.scrollLeft;
                    var scrollY_1 = container.scrollTop;
                    if (container === document.body) {
                        scrollX_1 = Math.max(window.scrollX, scrollX_1);
                        scrollY_1 = Math.max(window.scrollY, scrollY_1);
                        containerX = 0;
                        containerY = 0;
                    }
                    _this.setState({
                        position: {
                            left: position.left + scrollX_1 - containerX,
                            top: position.top + scrollY_1 - containerY,
                        },
                        actualPlacement: position.placement,
                    });
                }
            };
            setPosition();
        };
        _this.getTriggerHandle = function (visible, childHandle, needCalculate) {
            return function (e) {
                var rect = e.currentTarget.getBoundingClientRect();
                var cb = function () {
                    if (needCalculate) {
                        _this.calculateAndSetPosition(rect);
                    }
                };
                _this.setVisible(visible, cb, true);
                if (childHandle) {
                    childHandle(e);
                }
            };
        };
        _this.handleVisibleChange = function (visible) {
            _this.setVisible(visible, undefined, false);
        };
        _this.handleClickOutside = function () {
            if (_this.props.trigger === 'click') {
                _this.hide();
            }
        };
        _this.getTrigger = function () {
            var _a = _this.props.trigger, trigger = _a === void 0 ? 'hover' : _a;
            if (!triggers.includes(trigger)) {
                trigger = 'hover';
            }
            return trigger;
        };
        _this.renderChild = function () {
            var children = _this.props.children;
            if (!react_1.default.isValidElement(children)) {
                return null;
            }
            // 这里会重置原有的ref，需要优化
            var childrenProps = __assign(__assign({}, children.props), { ref: _this.triggerRef });
            var trigger = _this.getTrigger();
            var eventNames = [camelCase_1.default("on-" + trigger)];
            if (trigger === 'hover') {
                eventNames = ['onMouseEnter', 'onMouseLeave'];
            }
            if (trigger === 'focus') {
                eventNames.push('onBlur');
            }
            eventNames.forEach(function (eventName) {
                var childHandle = childrenProps[eventName];
                var visible = !['onMouseLeave', 'onBlur'].includes(eventName);
                childrenProps[eventName] = _this.getTriggerHandle(visible, childHandle, visible);
            });
            return react_1.default.cloneElement(react_1.default.Children.only(children), childrenProps);
        };
        _this.renderContent = function () {
            var content = _this.props.content;
            // 目前直接将实际的placement通过props传递给content组件，如后续使用起来不方便可改为钩子函数的方式传递
            var actualPlacement = _this.state.actualPlacement;
            if (!react_1.default.isValidElement(content)) {
                return null;
            }
            var props = __assign(__assign({}, content.props), { dataPlacement: actualPlacement });
            var trigger = _this.getTrigger();
            if (trigger === 'hover') {
                props.onMouseEnter = _this.getTriggerHandle(true, props.onMouseEnter, false);
                props.onMouseLeave = _this.getTriggerHandle(false, props.onMouseLeave, false);
            }
            return react_1.default.cloneElement(react_1.default.Children.only(content), props);
        };
        if (props.contentVisible) {
            _this.state = __assign(__assign({}, _this.state), { visible: props.contentVisible });
        }
        return _this;
    }
    Popup.prototype.componentDidMount = function () {
        var triggerEle = this.getTriggerEle();
        if (this.state.visible) {
            triggerEle && this.calculateAndSetPosition(triggerEle.getBoundingClientRect());
        }
        window.addEventListener('resize', this.handleResetPosition);
        window.addEventListener('scroll', this.handleResetPosition);
    };
    Popup.prototype.componentDidUpdate = function (prevProps) {
        var contentVisible = this.props.contentVisible;
        if (prevProps.contentVisible !== contentVisible && contentVisible !== this.state.visible) {
            this.setVisible(contentVisible || false);
        }
    };
    Popup.prototype.componentWillUnmount = function () {
        window.removeEventListener('resize', this.handleResetPosition);
        window.removeEventListener('scroll', this.handleResetPosition);
        if (this.timer) {
            clearTimeout(this.timer);
            this.timer = null;
        }
    };
    Popup.prototype.render = function () {
        var _a = this.state, visible = _a.visible, position = _a.position;
        var _b = this.props, motionClassName = _b.motionClassName, motionDuration = _b.motionDuration;
        return (react_1.default.createElement(react_1.default.Fragment, null,
            this.renderChild(),
            react_1.default.createElement(content_1.default, { visible: visible, position: position, getWrap: this.getContentWrap, container: this.getContainer(), motionDuration: motionDuration, motionClassName: motionClassName, onClickOutside: this.handleClickOutside, onVisibleChange: this.handleVisibleChange }, this.renderContent())));
    };
    Popup.defaultProps = {
        trigger: 'hover',
        placement: 'bottom',
        offset: 5,
        closeDelay: 100,
        openDelay: 100,
        getContainer: function () { return document.body; },
    };
    return Popup;
}(react_1.default.Component));
exports.default = Popup;
//# sourceMappingURL=index.js.map