"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
var react_1 = __importDefault(require("react"));
var enzyme_1 = require("enzyme");
var react_test_renderer_1 = __importDefault(require("react-test-renderer"));
var index_1 = __importDefault(require("../index"));
// checkbox
it('checkbox render correctly', function () {
    var tree = react_test_renderer_1.default.create(react_1.default.createElement(index_1.default, null)).toJSON();
    expect(tree).toMatchSnapshot();
});
it('checkbox onchange handler should be triggered', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(index_1.default, { onChange: onChange }));
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalled();
});
it('checkbox default props', function () {
    var wrapper = enzyme_1.mount(react_1.default.createElement(index_1.default, null, "onChangeTest"));
    expect(wrapper.props().indeterminate).toEqual(false);
});
it('disabled checkbox should not react onchange event', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(index_1.default, { disabled: true, onChange: onChange }));
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).not.toHaveBeenCalled();
});
it('checkbox indeterminate  ', function () {
    var tree = react_test_renderer_1.default.create(react_1.default.createElement(index_1.default, { indeterminate: true })).toJSON();
    expect(tree).toMatchSnapshot();
});
// checkbox group
it('checkbox group render correctly', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(index_1.default.Group, { options: ['Apple', 'Pear', 'Orange'], onChange: onChange }));
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith(['Apple']);
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(1)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith(['Apple', 'Pear']);
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(2)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith(['Apple', 'Pear', 'Orange']);
});
it('onChange should keep the order of the original values', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(index_1.default.Group, { onChange: onChange },
        react_1.default.createElement(index_1.default, { key: 1, value: 1 }),
        react_1.default.createElement(index_1.default, { key: 2, value: 2 }),
        react_1.default.createElement(index_1.default, { key: 3, value: 3 }),
        react_1.default.createElement(index_1.default, { key: 4, value: 4 })));
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith([1]);
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(1)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith([1, 2]);
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith([2]);
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith([1, 2]);
});
it('onChange should filter removed value', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(index_1.default.Group, { defaultValue: [1], onChange: onChange },
        react_1.default.createElement(index_1.default, { key: 1, value: 1 }),
        react_1.default.createElement(index_1.default, { key: 2, value: 2 })));
    wrapper.setProps({
        children: [react_1.default.createElement(index_1.default, { key: 2, value: 2 })],
    });
    wrapper
        .find('.oa-cuk-checkbox-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalledWith([2]);
});
//# sourceMappingURL=checkbox.test.js.map