import React from 'react';
import dayjs, { Dayjs } from 'dayjs';
import { TInputSize } from '../input/Input';
import Popup, { TriggerType } from '../_base/popup';
import { BaseProps } from '../_base/interface';
import { TLang } from './utils/I18n';
import { IDisableTime, ITimeStep } from './utils/calculate';
import './style/index.scss';
declare type CurrentType = 'time' | 'month' | 'date' | 'year';
declare type ValueType = Dayjs | Date | string;
interface IProps extends BaseProps {
    type?: 'time' | 'month' | 'date' | 'dateTime';
    placeholder?: string;
    lang?: 'zh' | 'en';
    size?: TInputSize;
    clearable?: boolean;
    trigger?: TriggerType;
    value?: ValueType;
    defaultValue?: ValueType;
    format?: string;
    autoClose?: boolean;
    disabled?: boolean;
    disableTime?: IDisableTime;
    timeStep?: ITimeStep;
    onChange?: (value: Dayjs | null, valueStr: string) => void;
    disableDate?: (date: Dayjs) => boolean;
    onOk?: () => void;
    onClear?: () => void;
    getPopupContainer?: () => HTMLElement | false;
}
interface IState {
    currentType: CurrentType;
    value?: Dayjs;
    langData: TLang;
}
export default class DatePicker extends React.Component<IProps, IState> {
    static defaultProps: {
        trigger: string;
        type: string;
        lang: string;
        autoClose: boolean;
        clearable: boolean;
    };
    static getDerivedStateFromProps(props: IProps, state: IState): {
        value: dayjs.Dayjs | undefined;
    };
    popup: React.RefObject<Popup>;
    constructor(props: IProps);
    getPlaceholder: () => string;
    getInputIcon: () => JSX.Element;
    getFormat: () => string;
    handleChange: (value?: dayjs.Dayjs | undefined, needClose?: boolean) => void;
    handleClear: () => void;
    handleOk: () => void;
    renderPanel: () => JSX.Element;
    renderTrigger: () => JSX.Element;
    render(): JSX.Element;
}
export {};
