/// <reference types="react" />
declare const Placements: ["topLeft", "topCenter", "topRight", "bottomLeft", "bottomCenter", "bottomRight"];
export declare type Placement = typeof Placements[number];
export declare type MenuFunc = () => React.ReactNode;
/**
 * @property label {string} - 选项信息(可通过labelKey指定该字段名)
 * @property value {string} - 选项值(可通过valueKey指定该字段名)
 * @property prefix {ReactNode} - 选项前置icon(可通过prefixKey指定该字段名)
 * @property className {string} - 选项类名
 */
export declare type Option = {
    [key: string]: any;
};
export interface TriggerProps {
    prefixCls?: string;
    className?: string;
    triggerText?: string;
    trigger?: 'click' | 'hover';
    triggerBorderless?: boolean;
    triggerPrefix?: React.ReactNode;
    triggerSuffix?: React.ReactNode;
    isTriggerTextAppendable?: boolean;
}
export interface LazyLoadContainerProps {
    offset?: number;
    onScrollBottom?: () => void;
    loadingComponent?: React.ReactNode;
    isLoading?: boolean;
    className?: string;
}
export interface CommonDropdownProps extends Omit<React.HTMLAttributes<HTMLDivElement>, 'onSelect'> {
    menu?: React.ReactNode | MenuFunc;
    MenuItem?: React.ElementType;
    options?: Option[];
    labelKey?: string;
    valueKey?: string;
    prefixKey?: string;
    trigger?: 'click' | 'hover';
    onVisibleChange?: (visible: boolean) => void;
    visible?: boolean;
    onToggle?: (visible: boolean) => void;
    disabled?: boolean;
    getPopupContainer?: (triggerNode: HTMLElement) => HTMLElement;
    prefixCls?: string;
    className?: string;
    overlayClassName?: string;
    optionCls?: string;
    transitionName?: string;
    placement?: Placement;
    mouseEnterDelay?: number;
    mouseLeaveDelay?: number;
    openClassName?: string;
    multiple?: boolean;
    searchable?: boolean;
    searchPlaceholder?: string;
    emptySearchDesc?: string;
    clearable?: boolean;
    onClear?: (selected?: Option[]) => void;
    empty?: React.ReactNode;
    emptyDesc?: string;
}
export interface DropdownHOCProps extends CommonDropdownProps, TriggerProps, LazyLoadContainerProps {
    onSearch?: (val: string, options: Option[]) => Option[];
    onSelect?: (key: Option, selected?: Option[], e?: React.MouseEvent | React.KeyboardEvent) => void;
}
export interface DropdownHOCState {
    filteredOptions: Option[] | null;
    selected: Option[];
    visible: boolean;
    focusIndex: number;
    menuPosition: string;
}
export declare type FocusBy = 'arrow' | 'mouse';
export {};
