import React from 'react';
import { BaseProps } from '../_base/interface';
import './style/index.scss';
export declare type TInputSize = 'small' | 'default' | 'large' | 'xLarge';
export declare type TInputStatus = 'success' | 'default' | 'error' | 'warning';
export interface IProps extends BaseProps {
    type?: string;
    size?: TInputSize;
    value?: number | string;
    defaultValue?: number | string;
    clearable?: boolean;
    disabled?: boolean;
    readOnly?: boolean;
    maxLength?: number;
    focus?: boolean;
    before?: React.ReactNode;
    after?: React.ReactNode;
    prefix?: React.ReactNode;
    suffix?: React.ReactNode;
    status?: TInputStatus;
    id?: string;
    name?: string;
    placeholder?: string;
    showAffixOnlyMouseEnter?: boolean;
    onChange?: (value: string) => void;
    onClear?: () => void;
    onPressEnter?: (value: string) => void;
    onFocus?: (e?: React.FocusEvent) => void;
    onBlur?: (e?: React.FocusEvent) => void;
}
interface IState {
    value: number | string | undefined;
    active: boolean;
}
export default class Input extends React.Component<IProps, IState> {
    state: IState;
    static Search: React.ReactNode;
    static Textarea: React.ReactNode;
    static Number: React.ReactNode;
    static Group: React.ReactNode;
    static defaultProps: {
        clearable: boolean;
        defaultValue: string;
        placeholder: string;
        type: string;
    };
    static getDerivedStateFromProps(props: IProps, state: IState): {
        value: string | number | undefined;
    };
    constructor(props: IProps);
    input: React.RefObject<HTMLInputElement>;
    componentDidMount(): void;
    componentDidUpdate(prevProps: IProps): void;
    autoFocus: () => void;
    checkValueLength: (value: string | number | undefined, maxLength?: number | undefined) => string;
    handleMouseEnter: () => void;
    handleMouseLeave: () => void;
    handleKeyPress: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    handleChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
    handleClear: () => void;
    wrapInput: (input: React.ReactNode) => JSX.Element;
    renderInput: () => JSX.Element;
    renderAddonWrap: (child: React.ReactNode, isBefore: boolean) => JSX.Element;
    renderInputAndAddon: () => JSX.Element;
    render(): JSX.Element;
}
export {};
