"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var classnames_1 = __importDefault(require("classnames"));
var isEmpty_1 = __importDefault(require("lodash/isEmpty"));
var isNumber_1 = __importDefault(require("lodash/isNumber"));
var object_omit_1 = __importDefault(require("object.omit"));
var Close_1 = __importDefault(require("../icons/Close"));
var helper_1 = require("../_base/helper");
require("./style/index.scss");
var sizeMap = {
    small: 'input-small',
    large: 'input-large',
    xLarge: 'input-x-large',
};
var affixMap = {
    small: 'affix-small',
    large: 'affix-large',
    xLarge: 'affix-x-large',
};
var Input = /** @class */ (function (_super) {
    __extends(Input, _super);
    function Input(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            value: '',
            active: false,
        };
        _this.input = react_1.default.createRef();
        _this.autoFocus = function () {
            var focus = _this.props.focus;
            if (focus && _this.input && _this.input.current) {
                _this.input.current.focus();
            }
        };
        _this.checkValueLength = function (value, maxLength) {
            if (value == null) {
                return '';
            }
            value = "" + value;
            if (isNumber_1.default(maxLength) && maxLength > 0 && value.length > maxLength) {
                value = value.slice(0, maxLength);
            }
            return value;
        };
        _this.handleMouseEnter = function () {
            _this.setState({ active: true });
        };
        _this.handleMouseLeave = function () {
            _this.setState({ active: false });
        };
        _this.handleKeyPress = function (e) {
            var onPressEnter = _this.props.onPressEnter;
            if (e.charCode === 13 && onPressEnter) {
                var value = !isEmpty_1.default(_this.state.value) ? "" + _this.state.value : '';
                onPressEnter(value);
            }
        };
        _this.handleChange = function (e) {
            var _a = _this.props, onChange = _a.onChange, maxLength = _a.maxLength;
            var value = _this.checkValueLength(e.target.value, maxLength);
            _this.setState({ value: value });
            if (onChange) {
                onChange(value);
            }
        };
        _this.handleClear = function () {
            var _a = _this.props, onClear = _a.onClear, onChange = _a.onChange;
            _this.setState({ value: '' }, function () {
                if (onClear)
                    onClear();
                if (onChange)
                    onChange('');
            });
        };
        _this.wrapInput = function (input) {
            var _a = _this.props, clearable = _a.clearable, suffix = _a.suffix, prefix = _a.prefix, _b = _a.size, size = _b === void 0 ? '' : _b, style = _a.style, className = _a.className, disabled = _a.disabled, showAffixOnlyMouseEnter = _a.showAffixOnlyMouseEnter;
            var _c = _this.state, value = _c.value, active = _c.active;
            var clearVisible = clearable && active && !disabled;
            var showAffix = showAffixOnlyMouseEnter ? !disabled && active : true;
            var hasSuffix = suffix || clearVisible;
            var wrapStyle = {};
            /* 因为style会同时应用到wrap和input有些属性不想作用到wrap上，故做了过滤，
             ** 其实className也有同样的问题，目前没有想到更好的平衡方式。
             ** 分别用两个不同的Props? inputStyle 和 wrapStyle
             */
            if (style) {
                Object.keys(style).forEach(function (key) {
                    if (!/border/gi.test(key)) {
                        wrapStyle[key] = style[key];
                    }
                });
            }
            if (className) {
                wrapStyle.border = 'none';
            }
            var renderPrefix = function () {
                return prefix && showAffix ? (react_1.default.createElement("span", { className: helper_1.getClassName([
                        'input-affix',
                        'input-prefix',
                        affixMap[size],
                        { 'input-disabled': disabled },
                    ]) }, prefix)) : null;
            };
            var renderSuffix = function () {
                if (!hasSuffix || !showAffix) {
                    return null;
                }
                return (react_1.default.createElement("span", { className: helper_1.getClassName([
                        'input-affix',
                        'input-suffix',
                        affixMap[size],
                        { 'input-disabled': disabled },
                    ]) }, !isEmpty_1.default(value) && clearVisible ? (react_1.default.createElement("span", { className: helper_1.getClassName('input-clear-btn'), onClick: _this.handleClear },
                    react_1.default.createElement(Close_1.default, null))) : (suffix)));
            };
            return (react_1.default.createElement("span", { onMouseEnter: _this.handleMouseEnter, onMouseLeave: _this.handleMouseLeave, style: wrapStyle, className: classnames_1.default(helper_1.getClassName(['input-wrap', sizeMap[size]]), className) },
                renderPrefix(),
                input,
                renderSuffix()));
        };
        _this.renderInput = function () {
            var _a = _this.props, type = _a.type, disabled = _a.disabled, clearable = _a.clearable, suffix = _a.suffix, prefix = _a.prefix, className = _a.className, _b = _a.size, size = _b === void 0 ? '' : _b, others = __rest(_a, ["type", "disabled", "clearable", "suffix", "prefix", "className", "size"]);
            var active = _this.state.active;
            var resetProps = object_omit_1.default(others, [
                'focus',
                'defaultValue',
                'maxLength',
                'before',
                'after',
                'value',
                'onClear',
                'onPressEnter',
                'showAffixOnlyMouseEnter',
            ]);
            var hasWrap = clearable || suffix || prefix;
            var inputClassNames = ['input', sizeMap[size], { 'input-disabled': disabled }];
            if (active) {
                inputClassNames.push('input-active');
            }
            var input = (react_1.default.createElement("input", __assign({}, resetProps, { ref: _this.input, type: type, value: _this.state.value, onChange: _this.handleChange, onKeyPress: _this.handleKeyPress, disabled: disabled, className: classnames_1.default(helper_1.getClassName(inputClassNames), className) })));
            if (hasWrap) {
                return _this.wrapInput(input);
            }
            return input;
        };
        _this.renderAddonWrap = function (child, isBefore) {
            var size = _this.props.size;
            var classNames = ['input-addon', isBefore ? 'input-addon-before' : 'input-addon-after'];
            if (size) {
                classNames.push("input-addon-" + sizeMap[size]);
            }
            return react_1.default.createElement("span", { className: helper_1.getClassName(classNames) }, child);
        };
        _this.renderInputAndAddon = function () {
            var _a = _this.props, before = _a.before, after = _a.after;
            var input = _this.renderInput();
            if (!before && !after) {
                return input;
            }
            if (before) {
                before = _this.renderAddonWrap(before, true);
            }
            if (after) {
                after = _this.renderAddonWrap(after, false);
            }
            return (react_1.default.createElement("span", { className: helper_1.getClassName('input-group') },
                before,
                input,
                after));
        };
        var defaultValue = props.defaultValue, value = props.value, maxLength = props.maxLength;
        var currentValue = value || defaultValue;
        if (!isEmpty_1.default(currentValue)) {
            currentValue = _this.checkValueLength(currentValue, maxLength);
        }
        _this.state = { value: currentValue, active: false };
        return _this;
    }
    Input.getDerivedStateFromProps = function (props, state) {
        if (props.value !== undefined) {
            return { value: props.value };
        }
        return { value: state.value };
    };
    Input.prototype.componentDidMount = function () {
        this.autoFocus();
    };
    Input.prototype.componentDidUpdate = function (prevProps) {
        if (this.props.focus && !prevProps.focus) {
            this.autoFocus();
        }
    };
    Input.prototype.render = function () {
        return this.renderInputAndAddon();
    };
    Input.defaultProps = {
        clearable: false,
        defaultValue: '',
        placeholder: '请输入',
        type: 'text',
    };
    return Input;
}(react_1.default.Component));
exports.default = Input;
//# sourceMappingURL=Input.js.map