import React from 'react';
import Dialog from '../_base/dialog';
import { BaseProps } from '../_base/interface';
import './style/index.scss';
export interface IProps extends BaseProps {
    /** 控制是否可见 */
    visible: boolean;
    /** Modal标题，如不需要可传入null */
    title?: React.ReactNode;
    /** Modal底部内容，如不需要可传入null */
    footer?: React.ReactNode;
    /** 底部内容对齐方式 */
    footerAlign?: 'left' | 'center' | 'right';
    /** 内容类名 */
    className?: string;
    maskClassName?: string;
    maskStyle?: React.CSSProperties;
    /** 是否显示背景遮罩 */
    maskVisible?: boolean;
    /** 点击背景遮罩关闭弹窗 */
    maskCloseable?: boolean;
    /** 是否支持Esc键关闭 */
    escCloseable?: boolean;
    /** 是否显示关闭按钮 */
    closeable?: boolean;
    /** 是否居中显示 */
    centered?: boolean;
    /** 确定按钮文字 */
    okText?: string;
    /** 取消按钮文字 */
    cancelText?: string;
    /** 确定按钮Loading状态 */
    loading?: boolean;
    /** Modal内容的宽度，设置为null为自动宽度 */
    width?: number | string;
    /** Modal内容距离屏幕上方的距离，默认值10% */
    top?: number | string;
    /** 是否显示取消按钮 */
    cancelBtnVisible?: boolean;
    /** 是否显示确定按钮 */
    okBtnVisible?: boolean;
    /** 关闭事件回调 */
    onClose?: () => void;
    /** 确定按钮回调 */
    onOk?: () => void;
    /** 取消按钮回调 */
    onCancel?: () => void;
    icon?: React.ReactNode;
    getContainer?: () => HTMLElement;
    motionDuration?: number;
    iconColor?: string;
    children?: React.ReactNode;
}
export interface ConfirmProps extends IProps {
    content?: React.ReactNode;
    description?: React.ReactNode;
    whenOkDestroy?: boolean;
}
declare type ModalFunc = (props: ConfirmProps) => {
    destroy: () => void;
    update: (config: ConfirmProps) => void;
};
export default class Modal extends React.Component<IProps> {
    static defaultProps: {
        visible: boolean;
        maskVisible: boolean;
        closeable: boolean;
        escCloseable: boolean;
        maskCloseable: boolean;
        footer: boolean;
        footerAlign: string;
        cancelBtnVisible: boolean;
        okBtnVisible: boolean;
        centered: boolean;
        width: number;
        top: string;
        onClose: () => void;
        getContainer: () => HTMLElement;
    };
    static open: ModalFunc;
    static confirm: ModalFunc;
    static info: ModalFunc;
    static success: ModalFunc;
    static error: ModalFunc;
    static warning: ModalFunc;
    static destroyAll: () => void;
    dialog: React.RefObject<Dialog>;
    handleOk: () => void;
    handleClose: () => void;
    handleCancel: () => void;
    renderTitle: () => JSX.Element | null;
    renderFooter: () => JSX.Element | null;
    render(): JSX.Element;
}
export {};
