"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var react_test_renderer_1 = __importDefault(require("react-test-renderer"));
var enzyme_1 = require("enzyme");
var __1 = __importStar(require(".."));
var createRadioGroup = function (props) {
    var plainOptions = ['Apple', 'Pear', 'Orange'];
    var wrapper = enzyme_1.mount(react_1.default.createElement(__1.Group, __assign({ options: plainOptions }, props)));
    return wrapper;
};
// Radio
it('render correctly', function () {
    var tree = react_test_renderer_1.default.create(react_1.default.createElement(__1.default, null)).toJSON();
    expect(tree).toMatchSnapshot();
});
it('default checked radio render correctly', function () {
    var defaultCkeckedTree = react_test_renderer_1.default.create(react_1.default.createElement(__1.default, { defaultChecked: true })).toJSON();
    expect(defaultCkeckedTree).toMatchSnapshot();
});
it('add prefix class', function () {
    var tree = react_test_renderer_1.default.create(react_1.default.createElement(__1.default, { prefixCls: "oidar" })).toJSON();
    expect(tree).toMatchSnapshot();
});
it('onchange function should be called', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(__1.default, { onChange: onChange }));
    wrapper
        .find('.oa-cuk-radio-input')
        .at(0)
        .simulate('change');
    expect(onChange).toHaveBeenCalled();
});
it('disabled radio should not react onchange function', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(__1.default, { disabled: true, onChange: onChange }));
    wrapper
        .find('.oa-cuk-radio-input')
        .at(0)
        .simulate('change');
    expect(onChange).not.toHaveBeenCalled();
});
// Group
it('responses hover events', function () {
    var onMouseEnter = jest.fn();
    var onMouseLeave = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(__1.Group, { onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave },
        react_1.default.createElement(__1.default, null)));
    wrapper
        .find('div')
        .at(0)
        .simulate('mouseenter');
    expect(onMouseEnter).toHaveBeenCalled();
    wrapper
        .find('div')
        .at(0)
        .simulate('mouseleave');
    expect(onMouseLeave).toHaveBeenCalled();
});
it('radio rendered by option ', function () {
    var plainOptions = ['Apple', 'Pear', 'Orange'];
    var options = [
        { label: 'Apple', value: 'Apple' },
        { label: 'Pear', value: 'Pear' },
        { label: 'Orange', value: 'Orange' },
    ];
    var wrapper1 = enzyme_1.mount(react_1.default.createElement(__1.Group, { options: plainOptions }));
    expect(wrapper1.find('input').length).toBe(3);
    var wrapper2 = enzyme_1.mount(react_1.default.createElement(__1.Group, { options: options }));
    expect(wrapper2.find('input').length).toBe(3);
});
it('fire change events when value changes', function () {
    var onChange = jest.fn();
    var wrapper = createRadioGroup({ onChange: onChange });
    var radios = wrapper.find('input');
    // uncontrolled component
    wrapper.setState({ value: 'Pear' });
    radios.at(0).simulate('change');
    expect(onChange.mock.calls.length).toBe(1);
    // controlled component
    wrapper.setProps({ value: 'Apple' });
    radios.at(1).simulate('change');
    expect(onChange.mock.calls.length).toBe(2);
});
it("won't fire onchange function on selected value", function () {
    var onChange = jest.fn();
    var wrapper = createRadioGroup({ onChange: onChange });
    var radio = wrapper.find('input');
    wrapper.setState({ value: 'Apple' });
    radio.at(0).simulate('change');
    expect(onChange.mock.calls.length).toBe(0);
    wrapper.setState({ value: 'Pear' });
    radio.at(1).simulate('change');
    expect(onChange.mock.calls.length).toBe(0);
    wrapper.setState({ value: 'Orange' });
    radio.at(2).simulate('change');
    expect(onChange.mock.calls.length).toBe(0);
});
it('both RadioGroup and Radio will response for onchange event', function () {
    var onChange = jest.fn();
    var onChangeRadioGroup = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(__1.Group, { onChange: onChangeRadioGroup },
        react_1.default.createElement(__1.default, { value: "A", onChange: onChange }, "A"),
        react_1.default.createElement(__1.default, { value: "B", onChange: onChange }, "B"),
        react_1.default.createElement(__1.default, { value: "C", onChange: onChange }, "C")));
    var radios = wrapper.find('input');
    // uncontrolled component
    wrapper.setState({ value: 'B' });
    radios.at(0).simulate('change');
    expect(onChange.mock.calls.length).toBe(1);
    expect(onChangeRadioGroup.mock.calls.length).toBe(1);
    // controlled component
    wrapper.setProps({ value: 'A' });
    radios.at(1).simulate('change');
    expect(onChange.mock.calls.length).toBe(2);
});
it('both RadioGroup and radio Button will response for onchange event', function () {
    var onChange = jest.fn();
    var wrapper = enzyme_1.mount(react_1.default.createElement(__1.Group, { onChange: onChange },
        react_1.default.createElement(__1.Button, { value: "A" }, "A"),
        react_1.default.createElement(__1.Button, { value: "B" }, "B"),
        react_1.default.createElement(__1.Button, { value: "C" }, "C")));
    var radios = wrapper.find('input');
    // uncontrolled component
    wrapper.setState({ value: 'B' });
    radios.at(0).simulate('change');
    expect(onChange.mock.calls.length).toBe(1);
    // controlled component
    wrapper.setProps({ value: 'A' });
    radios.at(1).simulate('change');
    expect(onChange.mock.calls.length).toBe(2);
});
it('All group children should have name property', function () {
    var name = 'oa-cuk';
    var wrapper = createRadioGroup({ name: name });
    wrapper.find('input[type="radio"]').forEach(function (ele) {
        expect(ele.props().name === name);
    });
});
//# sourceMappingURL=radio.test.js.map