/// <reference types="react" />
import { TableProps as RcTableProps } from 'rc-table/lib/Table';
import { Store } from './createStore';
import { PaginationConfig } from '../pagination';
export declare type TableSize = 'default' | 'middle' | 'small';
export declare type SortOrder = 'descend' | 'ascend';
export declare type CompareFn<T> = (a: T, b: T, sortOrder?: SortOrder) => number;
export declare type InternalTableProps<T> = TableProps<T> & WithStore;
export interface WithStore {
    store: Store;
}
export interface TableCurrentDataSource<T> {
    currentDataSource: T[];
}
export interface SorterResult<T> {
    column: ColumnProps<T>;
    order: SortOrder;
    field: string;
    columnKey: string;
}
export interface ColumnProps<T> {
    key?: string;
    title?: React.ReactNode | ((options: {
        sortOrder?: SortOrder;
        sortColumn?: ColumnProps<T> | null;
    }) => React.ReactNode);
    dataIndex?: string;
    className?: string;
    sorter?: boolean | CompareFn<T>;
    sortDirections?: SortOrder[];
    sortOrder?: SortOrder | boolean;
    defaultSortOrder?: SortOrder;
}
export interface TableProps<T> extends Omit<RcTableProps<T>, 'columns' | 'scroll'> {
    id?: string;
    tableLayout?: 'auto' | 'fixed';
    prefixCls?: string;
    size?: TableSize;
    dataSource?: T[];
    columns: ColumnProps<T>[];
    useFixedHeader?: boolean;
    bordered?: boolean;
    emptyText?: React.ReactNode | (() => React.ReactNode);
    showHeader?: boolean;
    className?: string;
    style?: React.CSSProperties;
    children?: React.ReactNode;
    childrenColumnName?: string;
    pagination?: PaginationConfig | false;
    onChange?: (pagination: PaginationConfig, sorter: SorterResult<T>, extra: TableCurrentDataSource<T>) => void;
    scroll?: {
        x?: number | true | string;
        y?: number;
    };
}
export interface TableState<T> {
    pagination: PaginationConfig;
    sortColumn: ColumnProps<T> | null;
    sortOrder?: SortOrder;
    pivot?: number;
    prevProps: TableProps<T>;
    columns: ColumnProps<T>[];
}
export interface AdditionalCellProps {
    onClick?: React.MouseEventHandler<HTMLElement>;
    [name: string]: any;
}
export declare type PrepareParamsArgumentsReturn<T> = [any, string[], Object, {
    currentDataSource: T[];
}];
